@@ -4,7 +4,7 @@ import datetime
 import logging
 from dataclasses import asdict, dataclass
 from pathlib import Path
-from typing import Any, Iterable, List, Tuple
+from typing import Any, Iterable, List, Optional, Tuple
 
 import numpy as np
 import scipy.io as sio
@@ -34,7 +34,7 @@ class Solver:
     resnorm_maxiter: float = 6.0
 
 
-def _generate_cfg_dir(cfg_dir: Path = None) -> Path:
+def _generate_cfg_dir(cfg_dir: Optional[Path] = None) -> Path:
     """Make sure there is a working directory.
 
     Args:
@@ -97,12 +97,13 @@ class MarrmotM01(AbstractModel[MarrmotForcing]):
     # unable to subclass with more specialized arguments so ignore type
     def setup(  # type: ignore
         self,
-        maximum_soil_moisture_storage: float = None,
-        initial_soil_moisture_storage: float = None,
-        start_time: str = None,
-        end_time: str = None,
-        solver: Solver = None,
-        cfg_dir: str = None,
+        maximum_soil_moisture_storage: Optional[float] = None,
+        initial_soil_moisture_storage: Optional[float] = None,
+        start_time: Optional[str] = None,
+        end_time: Optional[str] = None,
+        solver: Optional[Solver] = None,
+        cfg_dir: Optional[str] = None,
+        delay: int = 0,
     ) -> Tuple[str, str]:
         """Configure model run.
 
@@ -122,6 +123,8 @@ class MarrmotM01(AbstractModel[MarrmotForcing]):
                 'YYYY-MM-DDTHH:MM:SSZ'. If not given then forcing end time is used.
             solver: Solver settings
             cfg_dir: a run directory given by user or created for user.
+            delay: Number of seconds to wait before communicating with model.
+                Increase the delay when model takes a while to start.
 
         Returns:
             Path to config file and path to config directory
@@ -147,6 +150,7 @@ class MarrmotM01(AbstractModel[MarrmotForcing]):
                 image=str(self.singularity_image),
                 work_dir=str(cfg_dir_as_path),
                 timeout=300,
+                delay=delay,
             )
         elif CFG["container_engine"].lower() == "docker":
             self.bmi = BmiClientDocker(
@@ -154,6 +158,7 @@ class MarrmotM01(AbstractModel[MarrmotForcing]):
                 image_port=55555,
                 work_dir=str(cfg_dir_as_path),
                 timeout=300,
+                delay=delay,
             )
         else:
             raise ValueError(
@@ -187,7 +192,10 @@ class MarrmotM01(AbstractModel[MarrmotForcing]):
             self.solver.resnorm_maxiter = forcing_solver["resnorm_maxiter"][0][0][0]
 
     def _create_marrmot_config(
-        self, cfg_dir: Path, start_time_iso: str = None, end_time_iso: str = None
+        self,
+        cfg_dir: Path,
+        start_time_iso: Optional[str] = None,
+        end_time_iso: Optional[str] = None,
     ) -> Path:
         """Write model configuration file.
 
@@ -345,19 +353,20 @@ class MarrmotM14(AbstractModel[MarrmotForcing]):
     # unable to subclass with more specialized arguments so ignore type
     def setup(  # type: ignore
         self,
-        maximum_soil_moisture_storage: float = None,
-        threshold_flow_generation_evap_change: float = None,
-        leakage_saturated_zone_flow_coefficient: float = None,
-        zero_deficit_base_flow_speed: float = None,
-        baseflow_coefficient: float = None,
-        gamma_distribution_chi_parameter: float = None,
-        gamma_distribution_phi_parameter: float = None,
-        initial_upper_zone_storage: float = None,
-        initial_saturated_zone_storage: float = None,
-        start_time: str = None,
-        end_time: str = None,
-        solver: Solver = None,
-        cfg_dir: str = None,
+        maximum_soil_moisture_storage: Optional[float] = None,
+        threshold_flow_generation_evap_change: Optional[float] = None,
+        leakage_saturated_zone_flow_coefficient: Optional[float] = None,
+        zero_deficit_base_flow_speed: Optional[float] = None,
+        baseflow_coefficient: Optional[float] = None,
+        gamma_distribution_chi_parameter: Optional[float] = None,
+        gamma_distribution_phi_parameter: Optional[float] = None,
+        initial_upper_zone_storage: Optional[float] = None,
+        initial_saturated_zone_storage: Optional[float] = None,
+        start_time: Optional[str] = None,
+        end_time: Optional[str] = None,
+        solver: Optional[Solver] = None,
+        cfg_dir: Optional[str] = None,
+        delay: int = 0,
     ) -> Tuple[str, str]:
         """Configure model run.
 
@@ -384,6 +393,8 @@ class MarrmotM14(AbstractModel[MarrmotForcing]):
                 'YYYY-MM-DDTHH:MM:SSZ'. If not given then forcing end time is used.
                 solver: Solver settings
             cfg_dir: a run directory given by user or created for user.
+            delay: Number of seconds to wait before communicating with model.
+                Increase the delay when model takes a while to start.
 
         Returns:
             Path to config file and path to config directory
@@ -414,6 +425,7 @@ class MarrmotM14(AbstractModel[MarrmotForcing]):
                 image=str(self.singularity_image),
                 work_dir=str(cfg_dir_as_path),
                 timeout=300,
+                delay=delay,
             )
         elif CFG["container_engine"].lower() == "docker":
             self.bmi = BmiClientDocker(
@@ -421,6 +433,7 @@ class MarrmotM14(AbstractModel[MarrmotForcing]):
                 image_port=55555,
                 work_dir=str(cfg_dir_as_path),
                 timeout=300,
+                delay=delay,
             )
         else:
             raise ValueError(
@@ -470,7 +483,10 @@ class MarrmotM14(AbstractModel[MarrmotForcing]):
             self.solver.resnorm_maxiter = forcing_solver["resnorm_maxiter"][0][0][0]
 
     def _create_marrmot_config(
-        self, cfg_dir: Path, start_time_iso: str = None, end_time_iso: str = None
+        self,
+        cfg_dir: Path,
+        start_time_iso: Optional[str] = None,
+        end_time_iso: Optional[str] = None,
     ) -> Path:
         """Write model configuration file.
 
